@@ -33,27 +33,6 @@ class Extractor:
         
     def extract(self):
         plugins = self._plugins() if self.custom_plugin_package is None else self.custom_plugin_package
-
-        # Time-windowed flows
-        '''
-        my_streamer = NFStreamer(source=self.input_pcap_filepath,
-                                decode_tunnels=True,
-                                bpf_filter=self.bpf_filter_string,
-                                promiscuous_mode=True,
-                                snapshot_length=1536,
-                                idle_timeout=1,
-                                active_timeout=1,
-                                accounting_mode=3,
-                                udps=plugins,
-                                n_dissections=20,
-                                statistical_analysis=True,
-                                splt_analysis=0,
-                                n_meters=0,
-                                performance_report=0)
-        
-        my_streamer.to_csv(path.join(self.output_dirpath,'out-timed-flows.csv'), columns_to_anonymize=[])
-        del my_streamer
-        '''
         
         # Sessions
         session_streamer = NFStreamer(source=self.input_pcap_filepath,
@@ -83,7 +62,13 @@ class Extractor:
         # HostsProcessor(sessions_df, self.output_dirpath).process()
         #print(6,h.heap())
         return path.join(self.output_dirpath,'out-sessions.csv')
-
+    
+    
+    def extract_many(self, input_pcap_filepaths, **kwargs):
+       for filepath in input_pcap_filepaths:
+           self.extract(filepath, **kwargs)
+           
+           
     def _plugins(self):
         return [
             ASNInfo(),
